---
title: <span class="badge builder"></span> HeatmapColorOptions
---
# <span class="badge builder"></span> HeatmapColorOptions

## Constructor

```python
HeatmapColorOptions()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> heatmap.HeatmapColorOptions
```

### <span class="badge object-method"></span> exponent

Controls the exponent when scale is set to exponential

```python
def exponent(exponent: float) -> typing.Self
```

### <span class="badge object-method"></span> fill

Controls the color fill when in opacity mode

```python
def fill(fill: str) -> typing.Self
```

### <span class="badge object-method"></span> max_val

Sets the maximum value for the color scale

```python
def max_val(max_val: float) -> typing.Self
```

### <span class="badge object-method"></span> min_val

Sets the minimum value for the color scale

```python
def min_val(min_val: float) -> typing.Self
```

### <span class="badge object-method"></span> mode

Sets the color mode

```python
def mode(mode: heatmap.HeatmapColorMode) -> typing.Self
```

### <span class="badge object-method"></span> reverse

Reverses the color scheme

```python
def reverse(reverse: bool) -> typing.Self
```

### <span class="badge object-method"></span> scale

Controls the color scale

```python
def scale(scale: heatmap.HeatmapColorScale) -> typing.Self
```

### <span class="badge object-method"></span> scheme

Controls the color scheme used

```python
def scheme(scheme: str) -> typing.Self
```

### <span class="badge object-method"></span> steps

Controls the number of color steps

```python
def steps(steps: int) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [HeatmapColorOptions](./object-HeatmapColorOptions.md)
